==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/azurestackhci/kotlin/inputs/VirtualMachinePropertiesHardwareProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurestackhci.kotlin.inputs

import com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesHardwareProfileArgs.builder
import com.pulumi.azurenative.azurestackhci.kotlin.enums.VmSizeEnum
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Double
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * HardwareProfile - Specifies the hardware settings for the virtual machine.
 * @property dynamicMemoryConfig
 * @property memoryMB RAM in MB for the virtual machine
 * @property processors number of processors for the virtual machine
 * @property vmSize
 */
public data class VirtualMachinePropertiesHardwareProfileArgs(
    public val dynamicMemoryConfig: Output<VirtualMachinePropertiesDynamicMemoryConfigArgs>? = null,
    public val memoryMB: Output<Double>? = null,
    public val processors: Output<Int>? = null,
    public val vmSize: Output<Either<String, VmSizeEnum>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesHardwareProfileArgs> {
    override fun toJava():
        com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesHardwareProfileArgs =
        com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesHardwareProfileArgs.builder()
            .dynamicMemoryConfig(
                dynamicMemoryConfig?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .memoryMB(memoryMB?.applyValue({ args0 -> args0 }))
            .processors(processors?.applyValue({ args0 -> args0 }))
            .vmSize(
                vmSize?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [VirtualMachinePropertiesHardwareProfileArgs].
 */
@PulumiTagMarker
public class VirtualMachinePropertiesHardwareProfileArgsBuilder internal constructor() {
    private var dynamicMemoryConfig: Output<VirtualMachinePropertiesDynamicMemoryConfigArgs>? = null

    private var memoryMB: Output<Double>? = null

    private var processors: Output<Int>? = null

    private var vmSize: Output<Either<String, VmSizeEnum>>? = null

    /**
     * @param value
     */
    @JvmName("yrcyfyjbilcbuhac")
    public suspend
    fun dynamicMemoryConfig(`value`: Output<VirtualMachinePropertiesDynamicMemoryConfigArgs>) {
        this.dynamicMemoryConfig = value
    }

    /**
     * @param value RAM in MB for the virtual machine
     */
    @JvmName("kpcdcphkgqlmfdoo")
    public suspend fun memoryMB(`value`: Output<Double>) {
        this.memoryMB = value
    }

    /**
     * @param value number of processors for the virtual machine
     */
    @JvmName("nnfqpkvjljjkacuk")
    public suspend fun processors(`value`: Output<Int>) {
        this.processors = value
    }

    /**
     * @param value
     */
    @JvmName("dkonvmnxphmehefy")
    public suspend fun vmSize(`value`: Output<Either<String, VmSizeEnum>>) {
        this.vmSize = value
    }

    /**
     * @param value
     */
    @JvmName("ribdgphvinofnayd")
    public suspend
    fun dynamicMemoryConfig(`value`: VirtualMachinePropertiesDynamicMemoryConfigArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dynamicMemoryConfig = mapped
    }

    /**
     * @param argument
     */
    @JvmName("hlfxowdvrahsnmxm")
    public suspend
    fun dynamicMemoryConfig(argument: suspend VirtualMachinePropertiesDynamicMemoryConfigArgsBuilder.() -> Unit) {
        val toBeMapped = VirtualMachinePropertiesDynamicMemoryConfigArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.dynamicMemoryConfig = mapped
    }

    /**
     * @param value RAM in MB for the virtual machine
     */
    @JvmName("tndgxvomljfxifhu")
    public suspend fun memoryMB(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.memoryMB = mapped
    }

    /**
     * @param value number of processors for the virtual machine
     */
    @JvmName("aircqroytvqffcue")
    public suspend fun processors(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.processors = mapped
    }

    /**
     * @param value
     */
    @JvmName("saeihuhdgbrnaayy")
    public suspend fun vmSize(`value`: Either<String, VmSizeEnum>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vmSize = mapped
    }

    /**
     * @param value
     */
    @JvmName("msxhmgsornrblcdm")
    public fun vmSize(`value`: String) {
        val toBeMapped = Either.ofLeft<String, VmSizeEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.vmSize = mapped
    }

    /**
     * @param value
     */
    @JvmName("dmojhbxugxkayecv")
    public fun vmSize(`value`: VmSizeEnum) {
        val toBeMapped = Either.ofRight<String, VmSizeEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.vmSize = mapped
    }

    internal fun build(): VirtualMachinePropertiesHardwareProfileArgs =
        VirtualMachinePropertiesHardwareProfileArgs(
            dynamicMemoryConfig = dynamicMemoryConfig,
            memoryMB = memoryMB,
            processors = processors,
            vmSize = vmSize,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/azurestackhci/kotlin/inputs/VirtualMachinePropertiesHardwareProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurestackhci.kotlin.inputs

import com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesHardwareProfileArgs.builder
import com.pulumi.azurenative.azurestackhci.kotlin.enums.VmSizeEnum
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Double
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * HardwareProfile - Specifies the hardware settings for the virtual machine.
 * @property dynamicMemoryConfig
 * @property memoryMB RAM in MB for the virtual machine
 * @property processors number of processors for the virtual machine
 * @property vmSize
 */
public data class VirtualMachinePropertiesHardwareProfileArgs(
    public val dynamicMemoryConfig: Output<VirtualMachinePropertiesDynamicMemoryConfigArgs>? = null,
    public val memoryMB: Output<Double>? = null,
    public val processors: Output<Int>? = null,
    public val vmSize: Output<Either<String, VmSizeEnum>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesHardwareProfileArgs> {
    override fun toJava():
        com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesHardwareProfileArgs =
        com.pulumi.azurenative.azurestackhci.inputs.VirtualMachinePropertiesHardwareProfileArgs.builder()
            .dynamicMemoryConfig(
                dynamicMemoryConfig?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .memoryMB(memoryMB?.applyValue({ args0 -> args0 }))
            .processors(processors?.applyValue({ args0 -> args0 }))
            .vmSize(
                vmSize?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [VirtualMachinePropertiesHardwareProfileArgs].
 */
@PulumiTagMarker
public class VirtualMachinePropertiesHardwareProfileArgsBuilder internal constructor() {
    private var dynamicMemoryConfig: Output<VirtualMachinePropertiesDynamicMemoryConfigArgs>? = null

    private var memoryMB: Output<Double>? = null

    private var processors: Output<Int>? = null

    private var vmSize: Output<Either<String, VmSizeEnum>>? = null

    /**
     * @param value
     */
    @JvmName("givlrilmieyswtyt")
    public suspend
    fun dynamicMemoryConfig(`value`: Output<VirtualMachinePropertiesDynamicMemoryConfigArgs>) {
        this.dynamicMemoryConfig = value
    }

    /**
     * @param value RAM in MB for the virtual machine
     */
    @JvmName("cckpkcapfvgpgeth")
    public suspend fun memoryMB(`value`: Output<Double>) {
        this.memoryMB = value
    }

    /**
     * @param value number of processors for the virtual machine
     */
    @JvmName("tgwkmdewqlblnrnn")
    public suspend fun processors(`value`: Output<Int>) {
        this.processors = value
    }

    /**
     * @param value
     */
    @JvmName("oujgkcairknkkhaq")
    public suspend fun vmSize(`value`: Output<Either<String, VmSizeEnum>>) {
        this.vmSize = value
    }

    /**
     * @param value
     */
    @JvmName("fqfaqulqejgtyvei")
    public suspend
    fun dynamicMemoryConfig(`value`: VirtualMachinePropertiesDynamicMemoryConfigArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dynamicMemoryConfig = mapped
    }

    /**
     * @param argument
     */
    @JvmName("uajlgfopmvbxqksv")
    public suspend
    fun dynamicMemoryConfig(argument: suspend VirtualMachinePropertiesDynamicMemoryConfigArgsBuilder.() -> Unit) {
        val toBeMapped = VirtualMachinePropertiesDynamicMemoryConfigArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.dynamicMemoryConfig = mapped
    }

    /**
     * @param value RAM in MB for the virtual machine
     */
    @JvmName("iglrukkuqpyihasn")
    public suspend fun memoryMB(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.memoryMB = mapped
    }

    /**
     * @param value number of processors for the virtual machine
     */
    @JvmName("icpuxgogsytnkfqn")
    public suspend fun processors(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.processors = mapped
    }

    /**
     * @param value
     */
    @JvmName("wqcdycjayyqmeuar")
    public suspend fun vmSize(`value`: Either<String, VmSizeEnum>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vmSize = mapped
    }

    /**
     * @param value
     */
    @JvmName("adxstfpjqfkfaxyd")
    public fun vmSize(`value`: String) {
        val toBeMapped = Either.ofLeft<String, VmSizeEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.vmSize = mapped
    }

    /**
     * @param value
     */
    @JvmName("csnbjcylkydmhscx")
    public fun vmSize(`value`: VmSizeEnum) {
        val toBeMapped = Either.ofRight<String, VmSizeEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.vmSize = mapped
    }

    internal fun build(): VirtualMachinePropertiesHardwareProfileArgs =
        VirtualMachinePropertiesHardwareProfileArgs(
            dynamicMemoryConfig = dynamicMemoryConfig,
            memoryMB = memoryMB,
            processors = processors,
            vmSize = vmSize,
        )
}
